summaryrefslogtreecommitdiffstats
path: root/os-plugins/plugins/vmware/OpenSLX/Distro/Debian.pm
diff options
context:
space:
mode:
Diffstat (limited to 'os-plugins/plugins/vmware/OpenSLX/Distro/Debian.pm')
-rw-r--r--os-plugins/plugins/vmware/OpenSLX/Distro/Debian.pm23
1 files changed, 16 insertions, 7 deletions
diff --git a/os-plugins/plugins/vmware/OpenSLX/Distro/Debian.pm b/os-plugins/plugins/vmware/OpenSLX/Distro/Debian.pm
index 5991d6ad..e1c7e2e4 100644
--- a/os-plugins/plugins/vmware/OpenSLX/Distro/Debian.pm
+++ b/os-plugins/plugins/vmware/OpenSLX/Distro/Debian.pm
@@ -52,11 +52,19 @@ sub fillRunlevelScript
### END INIT INFO
load_modules() {
- # to be filled in via the stage1 configuration script
- #TODO: everything behind || is not equal to Suse.pm
- modprobe -qa vmmon vmnet vmblock 2>/dev/null || echo "Problem here!"
- # most probably nobody wants to run the parallel port driver ...
- #modprobe vm...
+ if [ \${vmware_kind} = "local" ]; then
+ # to be filled in via the stage1 configuration script
+ modprobe -qa vmmon vmnet vmblock 2>/dev/null || return 1
+ # most probably nobody wants to run the parallel port driver ...
+ #modprobe vm...
+ else
+ # load module manuall
+ vmware_kind_path=/opt/openslx/plugin-repo/vmware/\${vmware_kind}/
+ module_src_path=\${vmware_kind_path}/root/lib/vmware/modules/source
+ insmod \${module_src_path}/vmblock.o
+ insmod \${module_src_path}/vmmon.o
+ insmod \${module_src_path}/vmnet.o
+ fi
}
unload_modules() {
# to be filled with the proper list within via the stage1 configuration
@@ -131,8 +139,9 @@ sub fillRunlevelScript
log_daemon_msg "Stopping vmware background services ..." "vmware"
killall vmnet-netifup vmnet-natd vmnet-bridge vmware vmplayer \\
vmware-tray vmnet-dhcpd 2>/dev/null
- # wait for shutting down of interfaces
- usleep 50000
+ # wait for shutting down of interfaces. vmnet needs kinda
+ # long
+ usleep 500000
unload_modules
log_end_msg $?
;;